Index: chrome/browser/webdata/web_database.h |
=================================================================== |
--- chrome/browser/webdata/web_database.h (revision 36778) |
+++ chrome/browser/webdata/web_database.h (working copy) |
@@ -204,13 +204,17 @@ |
// Updates the database values for the specified profile. |
bool UpdateAutoFillProfile(const AutoFillProfile& profile); |
- // Removes a row from the autofill_profiles table. |
- bool RemoveAutoFillProfile(const AutoFillProfile& profile); |
+ // Removes a row from the autofill_profiles table. |profile_id| is the |
+ // unique ID of the profile. |
+ bool RemoveAutoFillProfile(int profile_id); |
// Retrieves a profile with label |label|. The caller owns |profile|. |
bool GetAutoFillProfileForLabel(const string16& label, |
AutoFillProfile** profile); |
+ // Retrieves all profiles in the database. Caller owns the returned profiles. |
+ bool GetAutoFillProfiles(std::vector<AutoFillProfile*>* profiles); |
+ |
////////////////////////////////////////////////////////////////////////////// |
// |
// Web Apps |